@@ -2,11 +2,11 @@ library(bayesTFR)
 source('test_functions.R')
 
 cran <- TRUE
-for(wpp in rev(c(2010, 2012, 2015, 2017, 2019))) {
-	test.load.UNtfr(wpp)
-	test.load.UNlocations(wpp)
-	test.create.tfr.matrix(wpp)
-}
+
+wpp <- 2019
+test.load.UNtfr(wpp)
+test.load.UNlocations(wpp)
+test.create.tfr.matrix(wpp)
 test.load.UNtfr.and.my.tfr.file()
 test.existing.simulation()
 
@@ -20,16 +20,23 @@ if(!cran) {
 	test.median.adjust()
 	test.plot.map()
 	test.estimate.mcmc.with.suppl.data()
-	test.run.mcmc.simulation()
 	test.run.mcmc.simulation(compression='xz')
-	test.run.mcmc.simulation.with.uncertainty()
-	test.run.annual.simulation()
 	test.imputation()
-	test.thinned.simulation()
 	test.thinned.simulation(compression='bz')
 	test.run.mcmc.simulation.auto()
 	test.run.mcmc.simulation.auto.parallel()
 	test.plot.all()
 	test.reproduce.simulation()
 	test.subnational.predictions()
+	for (wpp in c(2019, 2022)){
+	    test.run.mcmc.simulation(wpp.year = wpp)
+	    test.run.mcmc.simulation.with.uncertainty(wpp.year = wpp)
+	    test.thinned.simulation(wpp.year = wpp)
+	    test.run.annual.simulation(wpp.year = wpp)
+	}
+	for(wpp in rev(c(2010, 2012, 2015, 2017, 2022))) { # these are either suggested packages or not on CRAN
+	    test.load.UNtfr(wpp)
+	    test.load.UNlocations(wpp)
+	    test.create.tfr.matrix(wpp)
+	}
 }
\ No newline at end of file
